@@ -9,7 +9,7 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.SSM 1.21.23\nVersion:         1.21.23.post1\nBuilder version:"
+        "Type annotations for boto3.SSM 1.21.25\nVersion:         1.21.25\nBuilder version:"
         " 7.4.1\nDocs:            https://vemel.github.io/boto3_stubs_docs/mypy_boto3_ssm//\nBoto3"
         " docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ssm.html#SSM\nOther"
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.21.23.post1")
+    print("1.21.25")
 
 
 def main() -> None:
